@@ -36,18 +36,18 @@ class HistoVisitor;
 class VisualAction : public BasicSceneObject {
 public:
     VisualAction();
-    virtual ~VisualAction();
+    virtual ~VisualAction() override;
 
-    void data(Data* data) { data_ = data; }
-    void set2D() {
+    void data(Data* data) override { data_ = data; }
+    void set2D() override {
         if (data_)
             data_->dimension(2);
     }
-    void visdef(Visdef* visdef) {
+    void visdef(Visdef* visdef) override {
         visdef->theme(theme());
         visdefs_.push_back(visdef);
     }
-    void binning(BinningObject* binning) {
+    void binning(BinningObject* binning) override {
         if (data_)
             data_->binning(binning);
     }
@@ -57,39 +57,39 @@ public:
     // A visual Action is valid, if the data have been set and the list of visdef is not empty!
     bool isValid() const { return data_ && visdefs_.empty() == false; }
 
-    bool needLegend();
-    void getReady(const LegendVisitor&);
+    bool needLegend() override;
+    void getReady(const LegendVisitor&) override;
 
 protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
-    virtual void print(ostream&) const;
-    void getReady();
-    void release();
+    virtual void print(ostream&) const override;
+    void getReady() override;
+    void release() override;
 
-    void visit(DrawingVisitor&);
-    void visit(TopAxisVisitor&);
-    void visit(LegendVisitor&);
-    void visit(TextVisitor&);
-    void visit(MetaDataVisitor&);
-    void visit(HistoVisitor&);
-    void visit(FrameVisitor&);
+    void visit(DrawingVisitor&) override;
+    void visit(TopAxisVisitor&) override;
+    void visit(LegendVisitor&) override;
+    void visit(TextVisitor&) override;
+    void visit(MetaDataVisitor&) override;
+    void visit(HistoVisitor&) override;
+    void visit(FrameVisitor&) override;
 
-    void visit(Transformation&);
+    void visit(Transformation&) override;
 
-    void visit(AnimationRules&);
+    void visit(AnimationRules&) override;
 
-    void visit(SceneLayer&, vector<LayoutVisitor*>&);
-    void visit(MetaDataCollector&);
-    void visit(ValuesCollector&);
-    void visit(DataIndexCollector&);
-    void visit(MagnifierCollector&);
+    void visit(SceneLayer&, vector<LayoutVisitor*>&) override;
+    void visit(MetaDataCollector&) override;
+    void visit(ValuesCollector&) override;
+    void visit(DataIndexCollector&) override;
+    void visit(MagnifierCollector&) override;
 
     Data* data_;
     vector<Visdef*> visdefs_;
     StaticLayer* layer_;
 
-    void visit(DateDescription&);
-    void visit(LevelDescription&);
+    void visit(DateDescription&) override;
+    void visit(LevelDescription&) override;
 
 private:
     //! Copy constructor - No copy allowed
@@ -109,7 +109,7 @@ private:
 class VisualAnimation : public VisualAction, public vector<BasicSceneObject*> {
 public:
     VisualAnimation();
-    virtual ~VisualAnimation();
+    virtual ~VisualAnimation() override;
     void loop(DataLoop* data) { loop_ = data; }
     DataLoop& loop() {
         ASSERT(loop_);
@@ -117,10 +117,10 @@ public:
     }
 
 protected:
-    void visit(MetaDataVisitor&);
-    void visit(Transformation&);
-    void visit(AnimationRules&);
-    void visit(SceneLayer&, vector<LayoutVisitor*>&);
+    void visit(MetaDataVisitor&) override;
+    void visit(Transformation&) override;
+    void visit(AnimationRules&) override;
+    void visit(SceneLayer&, vector<LayoutVisitor*>&) override;
 
     void prepare();
 
