@@ -26,13 +26,15 @@
 
 using namespace magics;
 
-Coastlines::Coastlines() {
+Coastlines::Coastlines() : layer_(0) {
     setInfo("_datatype", "Coastlines");
 }
 
 Coastlines::~Coastlines() {
-    if (layer_)
-        delete layer_;
+    if (layer_) {
+        // FIME: Double delete
+        // delete layer_;
+    }
 }
 
 /*!
@@ -102,6 +104,7 @@ void Coastlines::visit(SceneLayer& layer, vector<LayoutVisitor*>& visitors) {
     else
 #endif
     {
+        ASSERT(!layer_);
         // First we create the layer!
         // and push It to the parent layer!
         layer_ = new NoDataLayer(this);
