@@ -20,14 +20,11 @@
 */
 
 #include "IsoHelper.h"
-#include "AutoLock.h"
 #include "Timer.h"
+
 using namespace magics;
 
-#include "magics_windef.h"
-#ifdef MAGICS_ON_WINDOWS
 #include <iterator>
-#endif
 
 
 IsoHelper::IsoHelper(int n, vector<magics::Polyline*>& lines, IsoData& segments) :
@@ -85,7 +82,7 @@ void IsoHelper::print(ostream& out) const {
     out << "]";
 }
 
-static Mutex locklines_;
+static std::mutex locklines_;
 
 void IsoHelper::run() {
     deque<std::pair<double, pair<std::pair<double, double>, pair<double, double> > > > todo;
@@ -93,9 +90,9 @@ void IsoHelper::run() {
 
     while (true) {
         {  // Block
-            AutoLock<MutexCond> lock(data_.cond_);
+            std::unique_lock<std::mutex> lock(data_.mutex_);
             while (data_.more_ && data_.segments_.size() < 2000)
-                data_.cond_.wait();
+                data_.cond_.wait(lock);
 
             if (!data_.more_ && data_.segments_.empty()) {
                 for (map<double, vector<magics::Polyline*> >::iterator level = helpers_.begin();
@@ -104,7 +101,7 @@ void IsoHelper::run() {
                          ++line)
 
                         if (!(*line)->empty()) {
-                            AutoLock<Mutex> locklines(locklines_);
+                            std::lock_guard<std::mutex> locklines(locklines_);
                             lines_.push_back(*line);
                         }
 
@@ -112,7 +109,7 @@ void IsoHelper::run() {
                 return;
             }
             {
-                AutoLock<Mutex> locklines(locklines_);
+                std::lock_guard<std::mutex> locklines(locklines_);
                 // Deal with the segments
                 if (data_.segments_.size() > 2000 || !data_.more_) {
                     todo.clear();
@@ -120,11 +117,11 @@ void IsoHelper::run() {
                     data_.segments_.clear();
                 }
             }
-            data_.cond_.signal();
+            data_.cond_.notify_one();
         }
 
         {
-            AutoLock<Mutex> locklines(locklines_);
+            std::lock_guard<std::mutex> locklines(locklines_);
             for (deque<std::pair<double, pair<std::pair<double, double>, pair<double, double> > > >::iterator x =
                      todo.begin();
                  x != todo.end(); ++x) {
